Computing mean/median CI ratio and significant Discoveries
ciratio.RdPerfroms full model boostrap, stepwise AIC, stepwise BIc, lasso and MCP and gives average CI for variables adjusting for post-selectino inference using hybrid, bootstrap and selective inference
Arguments
- formula
a formula
- data
data set
- family
outcome distributional family
- nonselection
A character string specifying how to handle variables not selected by model selection procedure. One of "ignored", "confident_nulls" or "uncertain_nulls" supported
- conf.level
.95 by default
- B
Number of bootstraps
- direction
the mode of step wise search, can be one of "both", "backward", or "forward", with a default of "forward"
- select_factors_together
should categorical variables be jointly selected?
- debias
should estimates be debiased in bootstrap
- inference_target
is inference requested on all or selected only
- ...
additional arguments